LinePlot class

Inheritance

Constructors

LinePlot(List<String> names, List<Color> colors, List<String> labels, List<int> yValues, List<List<int>> values, double x1Trackball)

Properties

colors → List<Color>
final
hashCode → int
The hash code for this object.
no setterinherited
labels → List<String>
final
names → List<String>
final
positionAxleX ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder → SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
values ↔ List<List<int>>
getter/setter pair
x1Trackball → double
final
xPoints ↔ List<List<Offset>>
getter/setter pair
yPoints ↔ List<List<Offset>>
getter/setter pair
yValues → List<int>
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
desenha uma linha que liga dois pontos
drawPoint(Canvas canvas, Size size, List<List<int>> values, List<List<Offset>> xPoints, List<List<Offset>> yPoints, List<int> yValues) → void
vai desenhar o ponto de encontro entre os eixos x e y
drawXAxis(Canvas canvas, Size size) → List<int>
designs the x axis canvas: is the object we are going to draw size: is the size of the area where we are going to draw returns an array of int values containing: coordinates where we'll start building the markers of this axis
drawXMarkers(Canvas canvas, Size size, double startX) → void
desenha marcadores no eixo X - as labels
drawYMarkers(Canvas canvas, Size size, double startX) → void
desenha marcadores no eixo Y, o desenho destes marcadores é feito de cima para baixo
getCustomPaint(Color color, double strokeWidth, PaintingStyle style) → dynamic
hitTest(Offset position) → bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
size: é o tamanho da area onde vamos desenhar canvas: é o objeto que vamos desenhar paint: é o objeto que contém as propriedades do que desejamos desenhar: cor, espessura da linha, etc
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) → bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant CustomPainter oldDelegate) → bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited